@@ -1,7 +1,10 @@
 <?php
 
+declare(strict_types=1);
+
 namespace LaminasTest\EventManager;
 
+use Closure;
 use Laminas\EventManager\Event;
 use Laminas\EventManager\EventInterface;
 use Laminas\EventManager\EventManager;
@@ -10,12 +13,12 @@ use Laminas\EventManager\ResponseCollection;
 use Laminas\EventManager\SharedEventManager;
 use Laminas\EventManager\SharedEventManagerInterface;
 use PHPUnit\Framework\TestCase;
-use Prophecy\PhpUnit\ProphecyTrait;
 use ReflectionProperty;
 use stdClass;
 
 use function array_keys;
 use function array_shift;
+use function array_values;
 use function array_walk;
 use function count;
 use function sort;
@@ -29,7 +32,9 @@ use function var_export;
 class EventManagerTest extends TestCase
 {
     use DeprecatedAssertions;
-    use ProphecyTrait;
+
+    private EventManager $events;
+    private string|null $message;
 
     protected function setUp(): void
     {
@@ -42,39 +47,54 @@ class EventManagerTest extends TestCase
     /**
      * Retrieve list of registered event names from a manager.
      *
-     * @return string[]
+     * @return list<string>
      */
-    public function getEventListFromManager(EventManager $manager): array
+    private function getEventListFromManager(EventManager $manager): array
     {
         $r = new ReflectionProperty($manager, 'events');
         $r->setAccessible(true);
-        return array_keys($r->getValue($manager));
+        $value = $r->getValue($manager);
+        self::assertIsArray($value);
+        $keys = array_keys($value);
+        self::assertContainsOnly('string', $keys);
+        /** @psalm-var list<string> */
+
+        return $keys;
     }
 
     /**
      * Return listeners for a given event.
      *
-     * @param string $event
-     * @return callable[]
+     * @return array<int, list<Closure>>
      */
-    public function getListenersForEvent($event, EventManager $manager): array
+    private function getListenersForEvent(string $event, EventManager $manager): array
     {
         $r = new ReflectionProperty($manager, 'events');
         $r->setAccessible(true);
         $events = $r->getValue($manager);
+        self::assertIsArray($events);
 
+        $out                 = [];
         $listenersByPriority = $events[$event] ?? [];
-        foreach ($listenersByPriority as $priority => &$listeners) {
-            $listeners = $listeners[0];
+        self::assertIsArray($listenersByPriority);
+        foreach ($listenersByPriority as $priority => $listeners) {
+            self::assertIsInt($priority);
+            self::assertIsArray($listeners);
+            self::assertArrayHasKey(0, $listeners);
+            self::assertIsArray($listeners[0]);
+            $list = array_values($listeners[0]);
+            self::assertContainsOnlyInstancesOf(Closure::class, $list);
+            /** @psalm-var list<Closure> $list */
+            $out[$priority] = $list;
         }
 
-        return $listenersByPriority;
+        return $out;
     }
 
-    /** @psalm-return array{event: 'test', events: EventInterface[], listener: callable} */
+    /** @psalm-return array{event: "test", events: EventManager, listener: callable} */
     public function testAttachShouldAddListenerToEvent(): array
     {
-        $listener = [$this, __METHOD__];
+        $listener  = static fn(): int => 0;
         $this->events->attach('test', $listener);
         $listeners = $this->getListenersForEvent('test', $this->events);
         // Get first (and only) priority queue of listeners for event
@@ -100,36 +120,43 @@ class EventManagerTest extends TestCase
     /**
      * @dataProvider eventArguments
      */
-    public function testAttachShouldAddReturnTheListener(string $event)
+    public function testAttachShouldAddReturnTheListener(string $event): void
     {
-        $listener = [$this, __METHOD__];
+        $listener = static fn(): int => 0;
         self::assertSame($listener, $this->events->attach($event, $listener));
     }
 
-    public function testAttachShouldAddEventIfItDoesNotExist()
+    public function testAttachShouldAddEventIfItDoesNotExist(): void
     {
         self::assertAttributeEmpty('events', $this->events);
-        $listener = $this->events->attach('test', [$this, __METHOD__]);
-        $events   = $this->getEventListFromManager($this->events);
+        $this->events->attach('test', static fn () => null);
+        $events = $this->getEventListFromManager($this->events);
         self::assertNotEmpty($events);
         self::assertContains('test', $events);
     }
 
-    public function testTriggerShouldTriggerAttachedListeners()
+    public function testTriggerShouldTriggerAttachedListeners(): void
     {
-        $listener = $this->events->attach('test', [$this, 'handleTestEvent']);
+        $handler = function (EventInterface $e): void {
+            $message = $e->getParam('message', '__NOT_FOUND__');
+            self::assertIsString($message);
+            $this->message = $message;
+        };
+        $this->events->attach('test', $handler);
         $this->events->trigger('test', $this, ['message' => 'test message']);
         self::assertEquals('test message', $this->message);
     }
 
-    public function testTriggerShouldReturnAllListenerReturnValues()
+    public function testTriggerShouldReturnAllListenerReturnValues(): void
     {
-        $this->events->attach('string.transform', function ($e) {
+        $this->events->attach('string.transform', function (EventInterface $e): string {
             $string = $e->getParam('string', '__NOT_FOUND__');
+            self::assertIsString($string);
             return trim($string);
         });
-        $this->events->attach('string.transform', function ($e) {
+        $this->events->attach('string.transform', function (EventInterface $e): string {
             $string = $e->getParam('string', '__NOT_FOUND__');
+            self::assertIsString($string);
             return str_rot13($string);
         });
         $responses = $this->events->trigger('string.transform', $this, ['string' => ' foo ']);
@@ -139,36 +166,42 @@ class EventManagerTest extends TestCase
         self::assertEquals(str_rot13(' foo '), $responses->last());
     }
 
-    public function testTriggerUntilShouldReturnAsSoonAsCallbackReturnsTrue()
+    public function testTriggerUntilShouldReturnAsSoonAsCallbackReturnsTrue(): void
     {
-        $this->events->attach('foo.bar', function ($e) {
+        $this->events->attach('foo.bar', function (EventInterface $e) {
             $string = $e->getParam('string', '');
+            self::assertIsString($string);
             $search = $e->getParam('search', '?');
+            self::assertIsString($search);
             return strpos($string, $search);
         });
-        $this->events->attach('foo.bar', function ($e) {
+        $this->events->attach('foo.bar', function (EventInterface $e) {
             $string = $e->getParam('string', '');
+            self::assertIsString($string);
             $search = $e->getParam('search', '?');
+            self::assertIsString($search);
             return strstr($string, $search);
         });
         $responses = $this->events->triggerUntil(
             [$this, 'evaluateStringCallback'],
             'foo.bar',
             $this,
-            ['string' => 'foo', 'search' => 'f']
+            ['string' => 'foo', 'search' => 'f'],
         );
         self::assertInstanceOf(ResponseCollection::class, $responses);
         self::assertSame(0, $responses->last());
     }
 
-    public function testTriggerResponseCollectionContains()
+    public function testTriggerResponseCollectionContains(): void
     {
-        $this->events->attach('string.transform', function ($e) {
+        $this->events->attach('string.transform', function (EventInterface $e): string {
             $string = $e->getParam('string', '');
+            self::assertIsString($string);
             return trim($string);
         });
-        $this->events->attach('string.transform', function ($e) {
+        $this->events->attach('string.transform', function (EventInterface $e): string {
             $string = $e->getParam('string', '');
+            self::assertIsString($string);
             return str_rot13($string);
         });
         $responses = $this->events->trigger('string.transform', $this, ['string' => ' foo ']);
@@ -177,19 +210,12 @@ class EventManagerTest extends TestCase
         self::assertFalse($responses->contains(' foo '));
     }
 
-    public function handleTestEvent(EventInterface $e): void
-    {
-        $message       = $e->getParam('message', '__NOT_FOUND__');
-        $this->message = $message;
-    }
-
-    /** @param mixed $value */
-    public function evaluateStringCallback($value): bool
+    public function evaluateStringCallback(mixed $value): bool
     {
         return ! $value;
     }
 
-    public function testTriggerUntilShouldMarkResponseCollectionStoppedWhenConditionMet()
+    public function testTriggerUntilShouldMarkResponseCollectionStoppedWhenConditionMet(): void
     {
         // @codingStandardsIgnoreStart
         $this->events->attach('foo.bar', function () { return 'bogus'; }, 4);
@@ -204,11 +230,12 @@ class EventManagerTest extends TestCase
         self::assertInstanceOf(ResponseCollection::class, $responses);
         self::assertTrue($responses->stopped());
         $result = $responses->last();
+        self::assertIsString($result);
         self::assertEquals('found', $result);
         self::assertFalse($responses->contains('zero'));
     }
 
-    public function testTriggerUntilShouldMarkResponseCollectionStoppedWhenConditionMetByLastListener()
+    public function testTriggerUntilShouldMarkResponseCollectionStoppedWhenConditionMetByLastListener(): void
     {
         // @codingStandardsIgnoreStart
         $this->events->attach('foo.bar', function () { return 'bogus'; });
@@ -217,7 +244,7 @@ class EventManagerTest extends TestCase
         $this->events->attach('foo.bar', function () { return 'found'; });
         // @codingStandardsIgnoreEnd
 
-        $responses = $this->events->triggerUntil(function ($result) {
+        $responses = $this->events->triggerUntil(function ($result): bool {
             return $result === 'found';
         }, 'foo.bar', $this);
         self::assertInstanceOf(ResponseCollection::class, $responses);
@@ -225,16 +252,16 @@ class EventManagerTest extends TestCase
         self::assertEquals('found', $responses->last());
     }
 
-    public function testResponseCollectionIsNotStoppedWhenNoCallbackMatchedByTriggerUntil()
+    public function testResponseCollectionIsNotStoppedWhenNoCallbackMatchedByTriggerUntil(): void
     {
         // @codingStandardsIgnoreStart
-        $this->events->attach('foo.bar', function () { return 'bogus'; }, 4);
-        $this->events->attach('foo.bar', function () { return 'nada'; }, 3);
-        $this->events->attach('foo.bar', function () { return 'found'; }, 2);
-        $this->events->attach('foo.bar', function () { return 'zero'; }, 1);
+        $this->events->attach('foo.bar', static function () { return 'bogus'; }, 4);
+        $this->events->attach('foo.bar', static function () { return 'nada'; }, 3);
+        $this->events->attach('foo.bar', static function () { return 'found'; }, 2);
+        $this->events->attach('foo.bar', static function () { return 'zero'; }, 1);
         // @codingStandardsIgnoreEnd
 
-        $responses = $this->events->triggerUntil(function ($result) {
+        $responses = $this->events->triggerUntil(static function (mixed $result): bool {
             return $result === 'never found';
         }, 'foo.bar', $this);
         self::assertInstanceOf(ResponseCollection::class, $responses);
@@ -242,13 +269,13 @@ class EventManagerTest extends TestCase
         self::assertEquals('zero', $responses->last());
     }
 
-    public function testCallingEventsStopPropagationMethodHaltsEventEmission()
+    public function testCallingEventsStopPropagationMethodHaltsEventEmission(): void
     {
         // @codingStandardsIgnoreStart
-        $this->events->attach('foo.bar', function ($e) { return 'bogus'; }, 4);
-        $this->events->attach('foo.bar', function ($e) { $e->stopPropagation(true); return 'nada'; }, 3);
-        $this->events->attach('foo.bar', function ($e) { return 'found'; }, 2);
-        $this->events->attach('foo.bar', function ($e) { return 'zero'; }, 1);
+        $this->events->attach('foo.bar', static function (): string { return 'bogus'; }, 4);
+        $this->events->attach('foo.bar', static function (EventInterface $e): string { $e->stopPropagation(true); return 'nada'; }, 3);
+        $this->events->attach('foo.bar', static function (): string { return 'found'; }, 2);
+        $this->events->attach('foo.bar', static function (): string { return 'zero'; }, 1);
         // @codingStandardsIgnoreEnd
 
         $responses = $this->events->trigger('foo.bar');
@@ -260,15 +287,19 @@ class EventManagerTest extends TestCase
         self::assertFalse($responses->contains('zero'));
     }
 
-    public function testCanAlterParametersWithinAEvent()
+    public function testCanAlterParametersWithinAEvent(): void
     {
-        // @codingStandardsIgnoreStart
-        $this->events->attach('foo.bar', function ($e) { $e->setParam('foo', 'bar'); });
-        $this->events->attach('foo.bar', function ($e) { $e->setParam('bar', 'baz'); });
-        // @codingStandardsIgnoreEnd
-        $this->events->attach('foo.bar', function ($e) {
+        $this->events->attach('foo.bar', static function (EventInterface $e): void {
+            $e->setParam('foo', 'bar');
+        });
+        $this->events->attach('foo.bar', static function (EventInterface $e): void {
+            $e->setParam('bar', 'baz');
+        });
+        $this->events->attach('foo.bar', static function (EventInterface $e): string {
             $foo = $e->getParam('foo', '__NO_FOO__');
+            self::assertIsString($foo);
             $bar = $e->getParam('bar', '__NO_BAR__');
+            self::assertIsString($bar);
             return $foo . ":" . $bar;
         });
 
@@ -276,74 +307,77 @@ class EventManagerTest extends TestCase
         self::assertEquals('bar:baz', $responses->last());
     }
 
-    public function testParametersArePassedToEventByReference()
+    public function testParametersArePassedToEventByReference(): void
     {
         $params = ['foo' => 'bar', 'bar' => 'baz'];
         $args   = $this->events->prepareArgs($params);
 
-        // @codingStandardsIgnoreStart
-        $this->events->attach('foo.bar', function ($e) { $e->setParam('foo', 'FOO'); });
-        $this->events->attach('foo.bar', function ($e) { $e->setParam('bar', 'BAR'); });
-        // @codingStandardsIgnoreEnd
+        $this->events->attach('foo.bar', static function (EventInterface $e): void {
+            $e->setParam('foo', 'FOO');
+        });
+        $this->events->attach('foo.bar', static function (EventInterface $e): void {
+            $e->setParam('bar', 'BAR');
+        });
 
-        $responses = $this->events->trigger('foo.bar', $this, $args);
+        $this->events->trigger('foo.bar', $this, $args);
         self::assertEquals('FOO', $args['foo']);
         self::assertEquals('BAR', $args['bar']);
     }
 
-    public function testCanPassObjectForEventParameters()
+    public function testCanPassObjectForEventParameters(): void
     {
         $params = (object) ['foo' => 'bar', 'bar' => 'baz'];
-        // @codingStandardsIgnoreStart
-        $this->events->attach('foo.bar', function ($e) { $e->setParam('foo', 'FOO'); });
-        $this->events->attach('foo.bar', function ($e) { $e->setParam('bar', 'BAR'); });
-        // @codingStandardsIgnoreEnd
+        $this->events->attach('foo.bar', static function (EventInterface $e): void {
+            $e->setParam('foo', 'FOO');
+        });
+        $this->events->attach('foo.bar', static function (EventInterface $e): void {
+            $e->setParam('bar', 'BAR');
+        });
 
-        $responses = $this->events->trigger('foo.bar', $this, $params);
+        $this->events->trigger('foo.bar', $this, $params);
         self::assertEquals('FOO', $params->foo);
         self::assertEquals('BAR', $params->bar);
     }
 
-    public function testCanPassEventObjectAsSoleArgumentToTriggerEvent()
+    public function testCanPassEventObjectAsSoleArgumentToTriggerEvent(): void
     {
         $event = new Event();
         $event->setName(__FUNCTION__);
         $event->setTarget($this);
         $event->setParams(['foo' => 'bar']);
-        $this->events->attach(__FUNCTION__, function ($e) {
+        $this->events->attach(__FUNCTION__, static function (EventInterface $e): EventInterface {
             return $e;
         });
         $responses = $this->events->triggerEvent($event);
         self::assertSame($event, $responses->last());
     }
 
-    public function testCanPassEventObjectAndCallbackToTriggerEventUntil()
+    public function testCanPassEventObjectAndCallbackToTriggerEventUntil(): void
     {
         $event = new Event();
         $event->setName(__FUNCTION__);
         $event->setTarget($this);
         $event->setParams(['foo' => 'bar']);
-        $this->events->attach(__FUNCTION__, function ($e) {
+        $this->events->attach(__FUNCTION__, static function (EventInterface $e): EventInterface {
             return $e;
         });
-        $responses = $this->events->triggerEventUntil(function ($r) {
+        $responses = $this->events->triggerEventUntil(static function (mixed $r): bool {
             return $r instanceof EventInterface;
         }, $event);
         self::assertTrue($responses->stopped());
         self::assertSame($event, $responses->last());
     }
 
-    public function testIdentifiersAreNotInjectedWhenNoSharedManagerProvided()
+    public function testIdentifiersAreNotInjectedWhenNoSharedManagerProvided(): void
     {
         $events      = new EventManager(null, [self::class, static::class]);
         $identifiers = $events->getIdentifiers();
-        self::assertIsArray($identifiers);
         self::assertEmpty($identifiers);
     }
 
-    public function testDuplicateIdentifiersAreNotRegistered()
+    public function testDuplicateIdentifiersAreNotRegistered(): void
     {
-        $sharedEvents = $this->prophesize(SharedEventManagerInterface::class)->reveal();
+        $sharedEvents = $this->createMock(SharedEventManagerInterface::class);
         $events       = new EventManager($sharedEvents, [self::class, static::class]);
         $identifiers  = $events->getIdentifiers();
         self::assertSame(count($identifiers), 1);
@@ -353,7 +387,7 @@ class EventManagerTest extends TestCase
         self::assertSame($identifiers[0], self::class);
     }
 
-    public function testIdentifierGetterSetters()
+    public function testIdentifierGetterSetters(): void
     {
         $identifiers = ['foo', 'bar'];
         $this->events->setIdentifiers($identifiers);
@@ -368,11 +402,11 @@ class EventManagerTest extends TestCase
         self::assertSame($expectedIdentifiers, $identifiers);
     }
 
-    public function testListenersAttachedWithWildcardAreTriggeredForAllEvents()
+    public function testListenersAttachedWithWildcardAreTriggeredForAllEvents(): void
     {
         $test         = new stdClass();
         $test->events = [];
-        $callback     = function ($e) use ($test) {
+        $callback     = static function (EventInterface $e) use ($test): void {
             $test->events[] = $e->getName();
         };
 
@@ -384,10 +418,10 @@ class EventManagerTest extends TestCase
         }
     }
 
-    public function testTriggerSetsStopPropagationFlagToFalse()
+    public function testTriggerSetsStopPropagationFlagToFalse(): void
     {
         $marker = (object) ['propagationIsStopped' => true];
-        $this->events->attach('foo', function ($e) use ($marker) {
+        $this->events->attach('foo', static function (EventInterface $e) use ($marker): void {
             $marker->propagationIsStopped = $e->propagationIsStopped();
         });
 
@@ -400,14 +434,14 @@ class EventManagerTest extends TestCase
         self::assertFalse($event->propagationIsStopped());
     }
 
-    public function testTriggerEventUntilSetsStopPropagationFlagToFalse()
+    public function testTriggerEventUntilSetsStopPropagationFlagToFalse(): void
     {
         $marker = (object) ['propagationIsStopped' => true];
-        $this->events->attach('foo', function ($e) use ($marker) {
+        $this->events->attach('foo', static function (EventInterface $e) use ($marker) {
             $marker->propagationIsStopped = $e->propagationIsStopped();
         });
 
-        $criteria = function ($r) {
+        $criteria = static function (): bool {
             return false;
         };
         $event    = new Event();
@@ -419,40 +453,40 @@ class EventManagerTest extends TestCase
         self::assertFalse($event->propagationIsStopped());
     }
 
-    public function testCreatesAnEventPrototypeAtInstantiation()
+    public function testCreatesAnEventPrototypeAtInstantiation(): void
     {
         self::assertAttributeInstanceOf(EventInterface::class, 'eventPrototype', $this->events);
     }
 
-    public function testSetEventPrototype()
+    public function testSetEventPrototype(): void
     {
-        $event = $this->prophesize(EventInterface::class)->reveal();
+        $event = $this->createMock(EventInterface::class);
         $this->events->setEventPrototype($event);
 
         self::assertAttributeSame($event, 'eventPrototype', $this->events);
     }
 
-    public function testSharedManagerClearListenersReturnsFalse()
+    public function testSharedManagerClearListenersReturnsFalse(): void
     {
         $shared = new SharedEventManager();
         self::assertFalse($shared->clearListeners('foo'));
     }
 
-    public function testResponseCollectionLastReturnsNull()
+    public function testResponseCollectionLastReturnsNull(): void
     {
         $responses = $this->events->trigger('string.transform', $this, ['string' => ' foo ']);
         self::assertNull($responses->last());
     }
 
-    public function testCanAddWildcardListenersAfterFirstTrigger()
+    public function testCanAddWildcardListenersAfterFirstTrigger(): void
     {
-        $this->events->attach('foo', function ($e) {
+        $this->events->attach('foo', static function (EventInterface $e): void {
             self::assertEquals('foo', $e->getName());
         });
         $this->events->trigger('foo');
 
         $triggered = false;
-        $this->events->attach('*', function ($e) use (&$triggered) {
+        $this->events->attach('*', static function (EventInterface $e) use (&$triggered): void {
             self::assertEquals('foo', $e->getName());
             $triggered = true;
         });
@@ -460,9 +494,9 @@ class EventManagerTest extends TestCase
         self::assertTrue($triggered, 'Wildcard listener was not triggered');
     }
 
-    public function testCanInjectSharedManagerDuringConstruction()
+    public function testCanInjectSharedManagerDuringConstruction(): void
     {
-        $shared = $this->prophesize(SharedEventManagerInterface::class)->reveal();
+        $shared = $this->createMock(SharedEventManagerInterface::class);
         $events = new EventManager($shared);
         self::assertSame($shared, $events->getSharedManager());
     }
@@ -485,21 +519,21 @@ class EventManagerTest extends TestCase
 
     /**
      * @dataProvider invalidEventsForAttach
-     * @param mixed $event
      */
-    public function testAttachRaisesExceptionForInvalidEventType($event)
+    public function testAttachRaisesExceptionForInvalidEventType(mixed $event): void
     {
-        $callback = function () {
+        $callback = static function (): void {
         };
         $this->expectException(Exception\InvalidArgumentException::class);
         $this->expectExceptionMessage('string');
+        /** @psalm-suppress MixedArgument */
         $this->events->attach($event, $callback);
     }
 
-    public function testCanClearAllListenersForAnEvent()
+    public function testCanClearAllListenersForAnEvent(): void
     {
         $events   = ['foo', 'bar', 'baz'];
-        $listener = function ($e) {
+        $listener = static function (): void {
         };
         foreach ($events as $event) {
             $this->events->attach($event, $listener);
@@ -510,7 +544,7 @@ class EventManagerTest extends TestCase
         self::assertCount(
             0,
             $this->getListenersForEvent('foo', $this->events),
-            'Event foo listeners were not cleared'
+            'Event foo listeners were not cleared',
         );
 
         foreach (['bar', 'baz'] as $event) {
@@ -519,19 +553,19 @@ class EventManagerTest extends TestCase
                 $this->getListenersForEvent($event, $this->events),
                 sprintf(
                     'Event %s listeners were cleared and should not have been',
-                    $event
-                )
+                    $event,
+                ),
             );
         }
     }
 
-    public function testWillTriggerSharedListeners()
+    public function testWillTriggerSharedListeners(): void
     {
         $name      = __FUNCTION__;
         $triggered = false;
 
         $shared = new SharedEventManager();
-        $shared->attach(self::class, $name, function ($event) use ($name, &$triggered) {
+        $shared->attach(self::class, $name, static function (EventInterface $event) use ($name, &$triggered): void {
             self::assertEquals($name, $event->getName());
             $triggered = true;
         });
@@ -542,13 +576,13 @@ class EventManagerTest extends TestCase
         self::assertTrue($triggered, 'Shared listener was not triggered');
     }
 
-    public function testWillTriggerSharedWildcardListeners()
+    public function testWillTriggerSharedWildcardListeners(): void
     {
         $name      = __FUNCTION__;
         $triggered = false;
 
         $shared = new SharedEventManager();
-        $shared->attach('*', $name, function ($event) use ($name, &$triggered) {
+        $shared->attach('*', $name, static function (EventInterface $event) use ($name, &$triggered): void {
             self::assertEquals($name, $event->getName());
             $triggered = true;
         });
@@ -561,9 +595,9 @@ class EventManagerTest extends TestCase
 
     /**
      * @depends testAttachShouldAddListenerToEvent
-     * @psalm-param array{event: 'test', events: EventInterface[], listener: callable} $dependencies
+     * @psalm-param array{event: 'test', events: EventManager, listener: callable} $dependencies
      */
-    public function testCanDetachListenerFromNamedEvent(array $dependencies)
+    public function testCanDetachListenerFromNamedEvent(array $dependencies): void
     {
         $event    = $dependencies['event'];
         $events   = $dependencies['events'];
@@ -576,9 +610,9 @@ class EventManagerTest extends TestCase
         self::assertNotContains($listener, $listeners);
     }
 
-    public function testDetachDoesNothingIfEventIsNotPresentInManager()
+    public function testDetachDoesNothingIfEventIsNotPresentInManager(): void
     {
-        $callback = function ($e) {
+        $callback = static function (): void {
         };
         $this->events->attach('foo', $callback);
         $this->events->detach($callback, 'bar');
@@ -588,17 +622,18 @@ class EventManagerTest extends TestCase
         self::assertContains($callback, $listeners);
     }
 
+    /** @return array{event_names: list<string>, events: EventManager, not_contains: string} */
     public function testCanDetachWildcardListeners(): array
     {
         $events           = ['foo', 'bar'];
-        $listener         = function ($e) {
+        $listener         = static function (): string {
             return 'non-wildcard';
         };
-        $wildcardListener = function ($e) {
+        $wildcardListener = static function (): string {
             return 'wildcard';
         };
 
-        array_walk($events, function ($event) use ($listener) {
+        array_walk($events, function (string $event) use ($listener): void {
             $this->events->attach($event, $listener);
         });
         $this->events->attach('*', $wildcardListener);
@@ -610,6 +645,7 @@ class EventManagerTest extends TestCase
         self::assertEmpty($listeners);
 
         // Next, verify it's not in any of the specific event queues
+        /** @psalm-var list<string> $events */
         foreach ($events as $event) {
             $listeners = $this->getListenersForEvent($event, $this->events);
             // Get listeners for first and only priority queue
@@ -627,9 +663,9 @@ class EventManagerTest extends TestCase
 
     /**
      * @depends testCanDetachWildcardListeners
-     * @psalm-param array{event_names: string[], events: EventInterface[], not_contains: 'wildcard'} $dependencies
+     * @psalm-param array{event_names: list<string>, events: EventManager, not_contains: string} $dependencies
      */
-    public function testDetachedWildcardListenerWillNotBeTriggered(array $dependencies)
+    public function testDetachedWildcardListenerWillNotBeTriggered(array $dependencies): void
     {
         $eventNames  = $dependencies['event_names'];
         $events      = $dependencies['events'];
@@ -641,11 +677,11 @@ class EventManagerTest extends TestCase
         }
     }
 
-    public function testNotPassingEventNameToDetachDetachesListenerFromAllEvents()
+    public function testNotPassingEventNameToDetachDetachesListenerFromAllEvents(): void
     {
         $eventNames = ['foo', 'bar'];
         $events     = $this->events;
-        $listener   = function ($e) {
+        $listener   = static function (): string {
             return 'listener';
         };
 
@@ -662,9 +698,9 @@ class EventManagerTest extends TestCase
         }
     }
 
-    public function testCanDetachASingleListenerFromAnEventWithMultipleListeners()
+    public function testCanDetachASingleListenerFromAnEventWithMultipleListeners(): void
     {
-        $listener          = function ($e) {
+        $listener          = static function (): void {
         };
         $alternateListener = clone $listener;
 
@@ -680,8 +716,8 @@ class EventManagerTest extends TestCase
             sprintf(
                 'Listener count after attaching alternate listener for event %s was unexpected: %s',
                 'foo',
-                var_export($listeners, 1)
-            )
+                var_export($listeners, true),
+            ),
         );
         self::assertContains($listener, $listeners);
         self::assertContains($alternateListener, $listeners);
@@ -697,8 +733,8 @@ class EventManagerTest extends TestCase
             sprintf(
                 "Listener count after detaching listener for event %s was unexpected;\nListeners: %s",
                 'foo',
-                var_export($listeners, 1)
-            )
+                var_export($listeners, true),
+            ),
         );
         self::assertNotContains($listener, $listeners);
         self::assertContains($alternateListener, $listeners);
@@ -714,21 +750,21 @@ class EventManagerTest extends TestCase
 
     /**
      * @dataProvider invalidEventsForDetach
-     * @param mixed $event
      */
-    public function testPassingInvalidEventTypeToDetachRaisesException($event)
+    public function testPassingInvalidEventTypeToDetachRaisesException(mixed $event): void
     {
-        $listener = function ($e) {
+        $listener = static function (): void {
         };
 
         $this->expectException(Exception\InvalidArgumentException::class);
         $this->expectExceptionMessage('string');
+        /** @psalm-suppress MixedArgument */
         $this->events->detach($listener, $event);
     }
 
-    public function testDetachRemovesAllOccurrencesOfListenerForEvent()
+    public function testDetachRemovesAllOccurrencesOfListenerForEvent(): void
     {
-        $listener = function ($e) {
+        $listener = static function (): void {
         };
 
         for ($i = 0; $i < 5; $i += 1) {
@@ -748,18 +784,20 @@ class EventManagerTest extends TestCase
     /** @psalm-return array<string, array{0: string|EventInterface, 1: string, 2: null|callable}> */
     public function eventsMissingNames(): array
     {
-        $event = $this->prophesize(EventInterface::class);
-        $event->getName()->willReturn('');
-        $callback = function ($result) {
+        $event = $this->createMock(EventInterface::class);
+        $event->expects(self::atLeast(1))
+            ->method('getName')
+            ->willReturn('');
+        $callback = static function (): void {
         };
 
         // @codingStandardsIgnoreStart
         //                                      [ event,             method to trigger, callback ]
         return [
-            'trigger-empty-string'           => ['',               'trigger',           null],
-            'trigger-until-empty-string'     => ['',               'triggerUntil',      $callback],
-            'trigger-event-empty-name'       => [$event->reveal(), 'triggerEvent',      null],
-            'trigger-event-until-empty-name' => [$event->reveal(), 'triggerEventUntil', $callback],
+            'trigger-empty-string'           => ['',     'trigger',           null],
+            'trigger-until-empty-string'     => ['',     'triggerUntil',      $callback],
+            'trigger-event-empty-name'       => [$event, 'triggerEvent',      null],
+            'trigger-event-until-empty-name' => [$event, 'triggerEventUntil', $callback],
         ];
         // @codingStandardsIgnoreEnd
     }
@@ -772,7 +810,7 @@ class EventManagerTest extends TestCase
         $event,
         string $method,
         ?callable $callback
-    ) {
+    ): void {
         $this->expectException(Exception\RuntimeException::class);
         $this->expectExceptionMessage('missing a name');
         if ($callback) {
@@ -782,52 +820,68 @@ class EventManagerTest extends TestCase
         }
     }
 
-    public function testTriggerEventAcceptsEventInstanceAndTriggersListeners()
+    public function testTriggerEventAcceptsEventInstanceAndTriggersListeners(): void
     {
-        $event = $this->prophesize(EventInterface::class);
-        $event->getName()->willReturn('test');
-        $event->stopPropagation(false)->shouldBeCalled();
-        $event->propagationIsStopped()->willReturn(false);
+        $event = $this->createMock(EventInterface::class);
+        $event->expects(self::atLeast(1))
+            ->method('getName')
+            ->willReturn('test');
+
+        $event->expects(self::once())
+            ->method('stopPropagation')
+            ->with(false);
+
+        $event->expects(self::atLeast(1))
+            ->method('propagationIsStopped')
+            ->willReturn(false);
 
         $triggered = false;
-        $this->events->attach('test', function ($e) use ($event, &$triggered) {
-            self::assertSame($event->reveal(), $e);
+        $this->events->attach('test', static function (EventInterface $e) use ($event, &$triggered): void {
+            self::assertSame($event, $e);
             $triggered = true;
         });
 
-        $this->events->triggerEvent($event->reveal());
+        $this->events->triggerEvent($event);
         self::assertTrue($triggered, 'Listener for event was not triggered');
     }
 
-    public function testTriggerEventUntilAcceptsEventInstanceAndTriggersListenersUntilCallbackEvaluatesTrue()
+    public function testTriggerEventUntilAcceptsEventInstanceAndTriggersListenersUntilCallbackEvaluatesTrue(): void
     {
-        $event = $this->prophesize(EventInterface::class);
-        $event->getName()->willReturn('test');
-        $event->stopPropagation(false)->shouldBeCalled();
-        $event->propagationIsStopped()->willReturn(false);
+        $event = $this->createMock(EventInterface::class);
+        $event->expects(self::atLeast(1))
+            ->method('getName')
+            ->willReturn('test');
 
-        $callback = function ($result) {
+        $event->expects(self::once())
+            ->method('stopPropagation')
+            ->with(false);
+
+        $event->expects(self::atLeast(1))
+            ->method('propagationIsStopped')
+            ->willReturn(false);
+
+        $callback = static function (mixed $result): bool {
             return $result === true;
         };
 
         $triggeredOne = false;
-        $this->events->attach('test', function ($e) use ($event, &$triggeredOne) {
-            self::assertSame($event->reveal(), $e);
+        $this->events->attach('test', static function (EventInterface $e) use ($event, &$triggeredOne): void {
+            self::assertSame($event, $e);
             $triggeredOne = true;
         });
 
         $triggeredTwo = false;
-        $this->events->attach('test', function ($e) use ($event, &$triggeredTwo) {
-            self::assertSame($event->reveal(), $e);
+        $this->events->attach('test', static function (EventInterface $e) use ($event, &$triggeredTwo): bool {
+            self::assertSame($event, $e);
             $triggeredTwo = true;
             return true;
         });
 
-        $this->events->attach('test', function ($e) {
-            $this->fail('Third listener was triggered and should not have been');
+        $this->events->attach('test', function () {
+            self::fail('Third listener was triggered and should not have been');
         });
 
-        $this->events->triggerEventUntil($callback, $event->reveal());
+        $this->events->triggerEventUntil($callback, $event);
         self::assertTrue($triggeredOne, 'First Listener for event was not triggered');
         self::assertTrue($triggeredTwo, 'First Listener for event was not triggered');
     }
